#!/usr/bin/python3 env
import curses
from time import sleep
import ihs_dl.backend
from math import *


screen = curses.initscr()
curses.noecho()
curses.cbreak()
curses.start_color()
screen.keypad( 1 )
curses.init_pair(1,curses.COLOR_BLACK, curses.COLOR_CYAN)
highlightText = curses.color_pair( 1 )
normalText = curses.A_NORMAL
screen.border( 0 )
curses.curs_set( 0 )
max_row = 10 #max number of rows
box = curses.newwin( max_row + 2, 64, 1, 1 )
box.box()



strings = (backend.titleList) #Import Backend title List
row_num = len( strings )

pages = int( ceil( row_num / max_row ) )
position = 1
page = 1
for i in range( 1, max_row + 1 ):
    if row_num == 0:
        box.addstr( 1, 1, "There aren't strings", highlightText )
    else:
        if (i == position):
            box.addstr( i, 2, str( i ) + " - " + strings[ i - 1 ], highlightText )
        else:
            box.addstr( i, 2, str( i ) + " - " + strings[ i - 1 ], normalText )
        if i == row_num:
            break

screen.refresh()
box.refresh()

x = screen.getch()
while x != 27:
    if x == curses.KEY_DOWN:
        if page == 1:
            if position < i:
                position = position + 1
            else:
                if pages > 1:
                    page = page + 1
                    position = 1 + ( max_row * ( page - 1 ) )
        elif page == pages:
            if position < row_num:
                position = position + 1
        else:
            if position < max_row + ( max_row * ( page - 1 ) ):
                position = position + 1
            else:
                page = page + 1
                position = 1 + ( max_row * ( page - 1 ) )
    if x == curses.KEY_UP:
        if page == 1:
            if position > 1:
                position = position - 1
        else:
            if position > ( 1 + ( max_row * ( page - 1 ) ) ):
                position = position - 1
            else:
                page = page - 1
                position = max_row + ( max_row * ( page - 1 ) )
    if x == curses.KEY_LEFT:
        if page > 1:
            page = page - 1
            position = 1 + ( max_row * ( page - 1 ) )

    if x == curses.KEY_RIGHT:
        if page < pages:
            page = page + 1
            position = ( 1 + ( max_row * ( page - 1 ) ) )
    if x == ord( "\n" ) and row_num != 0:
        screen.erase()
        screen.border( 0 )
        positionReturn = position-1
        backend.retrieveUrl(positionReturn)
        #screen.addstr( 14, 3, "Downloading Photos...")
        curses.endwin()
        print("Downloading Photos...")
        backend.downloadUrl(position)
        print("Photos Downloaded.")
        sleep(3)
        print("Exiting...")
        sleep(5)
        exit()


    box.erase()
    screen.border( 0 )
    box.border( 0 )

    for i in range( 1 + ( max_row * ( page - 1 ) ), max_row + 1 + ( max_row * ( page - 1 ) ) ):
        if row_num == 0:
            box.addstr( 1, 1, "There aren't strings",  highlightText )
        else:
            if ( i + ( max_row * ( page - 1 ) ) == position + ( max_row * ( page - 1 ) ) ):
                box.addstr( i - ( max_row * ( page - 1 ) ), 2, str( i ) + " - " + strings[ i - 1 ], highlightText )
            else:
                box.addstr( i - ( max_row * ( page - 1 ) ), 2, str( i ) + " - " + strings[ i - 1 ], normalText )
            if i == row_num:
                break



    screen.refresh()
    box.refresh()
    x = screen.getch()

curses.endwin()
exit()


import setuptools

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
	name = "ihs-dl",
	version = "0.0.2",
	license = "GPLv3",
	description = "IHS Markit Teardown Photo Downloader",
	author = "DerNuntius",
	author_email = "hugo@melder.xyz",
	long_description=long_description,
	long_description_content_type='text/markdown',
	packages = setuptools.find_packages(),
	classifiers = [
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: GNU General Public License (GPL)",
		"Operating System :: OS Independent",
    	],
	platforms = "any",
	install_requires = ["beautifulsoup4"],
	entry_points={'console_scripts': [ 'ihs-dl = ihs_dl:backend', ]}	
)



#!/usr/bin/python3 env
from urllib.request import urlopen
from bs4 import BeautifulSoup
import urllib.request
import re
import json

query = input("Enter your search term: ").replace(" ", "%20")
downloadPath = input("Select a download path (i.e /tmp/): ")
pages = input("Modify Search Query (Pages are cycled through) Enter = Default: ")

if pages == "":
	pages = 2	#Default Cycle

deviceList = []
titleList = []
pagesUrl = 1

for i in range(int(pages)):
    html = urlopen("https://benchmarking.ihsmarkit.com/teardowns?q="+ str(query) +"&pageNumber="+ str(pagesUrl) +"&o=") # Extraction URL
    bsObj = BeautifulSoup(html.read(), "html.parser")

    for link in bsObj.find_all('a', href=re.compile('^/Teardowns/detail/')): # Lists all internal teardown links and splits the Query IDs
        getLinks = link.get('href').split("=")
        otherID = (getLinks[1][:6]) #Purpose unknown
        deviceID = (getLinks[1][7:15])
        deviceList.append(deviceID)

    for title in bsObj.find_all('div',attrs={"class" : "galleryText"}): # Extract all titles from the search result
        result = (title.text).strip()
        titleList.append(result)
    pagesUrl = pagesUrl+1

 #   if usrResponse in  titleList:
#JSON Extractor
photoList = []
labelList = []
phototitleList = []
deviceID = 2869
listPosition = 0

def retrieveUrl(positionReturn):
    array = 0
    response = urlopen("https://benchmarking.ihsmarkit.com/Teardowns/binary/devices/"+ str(deviceList[positionReturn]) +"/photos/")
    data = json.load(response)
    for item in data:
        json_str = json.dumps(data[int(array)])
        resp = json.loads(json_str)
        photoList.append(resp['PhotoID'])
        labelList.append(resp["FileName"])
        phototitleList.append(resp["Label"].replace("/", ""))
        array = array+1

def downloadUrl(position):
    counter = 0
    for item in photoList: #Downloading Photos with information from backend
        url = "https://benchmarking.ihsmarkit.com/Teardowns/binary/devices/"+ str(deviceList[int(position-1)]) +"/photos/"+ str(photoList[counter]) +"/binary" #Downloading
        urllib.request.urlretrieve(url, str(downloadPath)+ "/" + str(phototitleList[counter]) +".jpg") #Download path
        counter = counter+1